@@ -322,7 +322,8 @@ class NapariStorage():
         else:
             array_data = np.array(napari_layer)
         return array_data
-
+    # This function might be changed in case the hdf5
+    # compression protocol is changed! 
     def filled_slices(self, layer_type: str, layer_name: str) -> list:
         '''
         Returns a list of indices specifying which slices have labels
@@ -331,13 +332,14 @@ class NapariStorage():
         napari_layer = self.f[layer_type][layer_name]
         data = np.array(napari_layer)
         if layer_type == 'labels':
-            if napari_layer.attrs['compressed']:
+            if napari_layer.attrs['is_sparse']:
                 # check if the sparse label includes z-dim
                 if napari_layer.shape[0] > 3:
                     return list(np.unique(data[0, :]))
             else:
                 if len(data.shape) > 2:
-                    return data.shape[0]  # non-sparse array
+                    return [z_slice for z_slice in range(data.shape[0]) 
+                            if len(np.unique(data[0, :])) > 1]
         return [0]  # when the images are 2D there is only one slice
 
     def excluded_layers(self) -> dict:
@@ -363,7 +365,7 @@ class NapariStorage():
         Returns the number of dimensions of Napari layer
         '''
         napari_layer = self.f[layer_type][layer_name]
-        if layer_type == 'labels' and napari_layer.attrs['compressed']:
+        if layer_type == 'labels' and napari_layer.attrs['is_sparse']:
             shape = napari_layer.attrs['shape']
         else:
             shape = napari_layer.shape
